@@ -1,13 +1,13 @@
 import random
 import string
 import uuid
+from inspect import getmembers, isfunction
 
 from django.contrib.auth.models import User
-from django.test import TestCase, Client
+from django.test import Client, TestCase
 from django.urls import reverse
 from rest_framework import status
 from rest_framework.test import APIClient
-from inspect import getmembers, isfunction
 
 
 def id_generator(size=6, chars=string.ascii_uppercase + string.digits):
@@ -52,30 +52,30 @@ class TestAdminTestCase(SetupClass):
     def run_for_model(self, model: str, **kwargs):
         if kwargs.get('is_check_add', True):
             response = self.client.get(
-                reverse('admin:{}_{}_add'.format(self.MODULE, model)),
+                reverse(f'admin:{self.MODULE}_{model}_add'),
                 follow=True
             )
             self.assertEqual(response.status_code, 200)
-            self.assertEqual(response.template_name[0], 'admin/{}/{}/change_form.html'.format(self.MODULE, model))
+            self.assertEqual(response.template_name[0], f'admin/{self.MODULE}/{model}/change_form.html')
 
         response = self.client.get(
-            reverse('admin:{}_{}_changelist'.format(self.MODULE, model)),
+            reverse(f'admin:{self.MODULE}_{model}_changelist'),
             follow=True
         )
         self.assertEqual(response.status_code, 200)
         if kwargs.get('is_check_template', True):
-            self.assertEqual(response.template_name[0], 'admin/{}/{}/change_list.html'.format(self.MODULE, model))
+            self.assertEqual(response.template_name[0], f'admin/{self.MODULE}/{model}/change_list.html')
 
         if kwargs.get('is_check_search', False):
             response = self.client.get(
                 "{}?q={}".format(
-                    reverse('admin:{}_{}_changelist'.format(self.MODULE, model)),
+                    reverse(f'admin:{self.MODULE}_{model}_changelist'),
                     "test"
                 ),
                 follow=True
             )
             self.assertEqual(response.status_code, 200)
-            self.assertEqual(response.template_name[0], 'admin/{}/{}/change_list.html'.format(self.MODULE, model))
+            self.assertEqual(response.template_name[0], f'admin/{self.MODULE}/{model}/change_list.html')
 
 
 class BaseTestApiAuthorization(TestCase):
@@ -90,7 +90,7 @@ class BaseTestApiAuthorization(TestCase):
     def setUp(self) -> None:
         super().setUp()
         user, created = User.objects.get_or_create(username=self.username, password=self.password)
-        admin_user = User.objects.create_superuser(
+        User.objects.create_superuser(
             username=self.admin_username,
             password=self.admin_password,
         )
@@ -128,7 +128,7 @@ class BaseTestAPIEndpointDoc(TestCase):
                 email='admin@talk-point.de',
                 password='@12345678',
             )
-        except:
+        except Exception:
             pass
 
     def test_doc(self):
@@ -148,7 +148,7 @@ class Representation(TestCase):
     def _test_representations_from_seeds(self, seeds):
         members = getmembers(seeds, isfunction)
 
-        for name, func in [x for x in members if "generate" in x[0]]:
+        for _name, func in [x for x in members if "generate" in x[0]]:
             model = func()
             if model is not None:
                 model.__repr__()
